@@ -2,7 +2,7 @@
                           kxmleditor.cpp  -  description
                              -------------------
     begin                : t ec 10 12:39:26 CEST 2001
-    copyright            : (C) 2001 by Lumir Vanek
+    copyright            : (C) 2001 by The KXMLEditor Team
     email                : lvanek@eanet.cz
  ***************************************************************************/
 
@@ -49,7 +49,7 @@ KXMLEditorApp::KXMLEditorApp(QWidget* , const char* name) : KMainWindow(0, name)
 {
   config=kapp->config();
 
-  readConfiguration();
+  OptionsDialog::readConfiguration(config);
 
   ///////////////////////////////////////////////////////////////////
   // call inits to invoke all other construction parts
@@ -186,15 +186,19 @@ void KXMLEditorApp::initActions()
 
 	m_Actions.xmlMoveItemUp = new KAction(i18n("Move &Up"), "xml_move_item_up", CTRL+Key_U, this, SLOT(slotXmlMoveItemUp()), actionCollection(), "xml_move_item_up");
 	m_Actions.xmlMoveItemDown = new KAction(i18n("Move &Down"), "xml_move_item_down", CTRL+Key_D, this, SLOT(slotXmlMoveItemDown()), actionCollection(), "xml_move_item_down");
-	
+
 	m_Actions.xmlExpandNode = new KToolBarPopupAction(i18n("&Expand Node"), "expand_node", CTRL+Key_Plus, this, SLOT(slotExpandNode()), actionCollection(), "expand_node");
-	connect(m_Actions.xmlExpandNode->popupMenu(), SIGNAL(aboutToShow()), this, SLOT(slotExpandNodeAboutToShow()));
-  connect(m_Actions.xmlExpandNode->popupMenu(), SIGNAL(activated(int)), this, SLOT(slotExpandNodeActivated(int)));
+	KPopupMenu * pMenuExpNode = m_Actions.xmlExpandNode->popupMenu();
+	connect( pMenuExpNode, SIGNAL(activated(int)), this, SLOT(slotExpandNodeActivated(int)));
+	for ( uint i = 1; i <= 8; i++ )
+		pMenuExpNode->insertItem( i18n("Expand to level %1").arg(i), i+1 );
 
 	m_Actions.xmlCollapseNode= new KToolBarPopupAction(i18n("&Collapse Node"), "collapse_node", CTRL+Key_Minus, this, SLOT(slotCollapseNode()), actionCollection(), "collapse_node");
-	connect(m_Actions.xmlCollapseNode->popupMenu(), SIGNAL(aboutToShow()), this, SLOT(slotCollapseNodeAboutToShow()));
-  connect(m_Actions.xmlCollapseNode->popupMenu(), SIGNAL(activated(int)), this, SLOT(slotCollapseNodeActivated(int)));
-	
+	KPopupMenu * pMenuColNode = m_Actions.xmlCollapseNode->popupMenu();
+	connect( pMenuColNode, SIGNAL(activated(int)), this, SLOT(slotCollapseNodeActivated(int)) );
+	for ( uint i = 1; i <= 8; i++ )
+		pMenuColNode->insertItem( i18n("Collapse to level %1").arg(i), i+1 );
+
 	//-----------------------------------------------------------------
 	// Popup menus
 	KXMLEditorView::m_pElementsMenu = new KPopupMenu;
@@ -346,18 +350,7 @@ config->setGroup("General Options");
   m_Actions.fileOpenRecent->saveEntries(config, "Recent Files");
 
   // save app settings
-  config->setGroup("Miscellaneous");
-  config->writeEntry("Root decorated", OptionsDialog::m_AppOptionsMisc.bRootDecorated);
-  config->writeEntry("Expand to level", OptionsDialog::m_AppOptionsMisc.iExpandToLevel);
-  config->writeEntry("Append CR LF", OptionsDialog::m_AppOptionsMisc.bAppendCRLF);
-  config->writeEntry("Enable DnD", OptionsDialog::m_AppOptionsMisc.bEnableDragDrop);
-  config->writeEntry("Element display mode", OptionsDialog::m_AppOptionsMisc.iElemDisplayMode);
-
-  config->setGroup("TarGz Extensions");	
-  config->writeEntry("Extensions", OptionsDialog::m_AppOptionsTarGzExt.strListOfTarGzExtensions);
-
-  config->setGroup("Spec. Characters");
-  config->writeEntry("Characters", OptionsDialog::m_AppOptionsSpecChars.strListOfSpecCharacters);
+	OptionsDialog::saveConfiguration(config);
 }
 
 
@@ -428,24 +421,6 @@ void KXMLEditorApp::saveProperties(KConfig *_cfg)
   }
 }
 
-/** Read user defined configuration */
-void KXMLEditorApp::readConfiguration()
-{
-  // read app settings
-	config->setGroup("Miscellaneous");
-  OptionsDialog::m_AppOptionsMisc.bRootDecorated = config->readBoolEntry("Root decorated", false);
-  OptionsDialog::m_AppOptionsMisc.iExpandToLevel = config->readNumEntry("Expand to level", 5);
-  OptionsDialog::m_AppOptionsMisc.bAppendCRLF = config->readBoolEntry("Append CR LF", false);
-  OptionsDialog::m_AppOptionsMisc.bEnableDragDrop = config->readBoolEntry("Enable DnD", true);
-	OptionsDialog::m_AppOptionsMisc.iElemDisplayMode = config->readNumEntry("Element display mode", 0);
-
-  config->setGroup("TarGz Extensions");
-  config->readListEntry("Extensions", OptionsDialog::m_AppOptionsTarGzExt.strListOfTarGzExtensions);
-
-	config->setGroup("Spec. Characters");
-  config->readListEntry("Characters", OptionsDialog::m_AppOptionsSpecChars.strListOfSpecCharacters);
-}
-
 void KXMLEditorApp::readProperties(KConfig* _cfg)
 {
   QString filename = _cfg->readEntry("filename", "");
@@ -493,7 +468,7 @@ bool KXMLEditorApp::queryExit()
 void KXMLEditorApp::slotFileNewWindow()
 {
   slotStatusMsg(i18n("Opening a new application window..."));
-	
+
   KXMLEditorApp *new_window= new KXMLEditorApp();
   new_window->show();
 
@@ -879,6 +854,7 @@ void KXMLEditorApp::slotPathComboActivated(const QString & szPath)
 void KXMLEditorApp::slotClearLocationBar()
 {
 	m_Actions.pathCombo->slotClearEdit();
+	m_Actions.pathCombo->slotFocusEdit();
 	view->slotUnselect();
 }
 
@@ -916,46 +892,16 @@ void KXMLEditorApp::slotCollapseNode()
 	view->collapseNode(-1);
 }
 
-/** Fill menu that is displayed when arrow is pressed
-on Expand Node button */
-void KXMLEditorApp::slotExpandNodeAboutToShow()
-{
-	QPopupMenu *popup = m_Actions.xmlExpandNode->popupMenu();
-  popup->clear();
-
-  // fill menu
-  uint i;
-  for(i = 2; i <= 8; i++)
-  	{ popup->insertItem(QPixmap(), i18n("Expand to level %1").arg(i));
-  	}
-}
-
-/** Fill menu that is displayed when arrow is pressed
-on Collapse Node button */
-void KXMLEditorApp::slotCollapseNodeAboutToShow()
-{
-	QPopupMenu *popup = m_Actions.xmlCollapseNode->popupMenu();
-  popup->clear();
-
-  // fill menu
-  unsigned int i;
-  for(i = 2; i <= 8; i++)  // it start from level 2
-  	{ popup->insertItem(QPixmap(), i18n("Collapse from level %1").arg(i));
-  	}
-}
-
 /** Called when menu item from Expand Node button is selected */
 void KXMLEditorApp::slotExpandNodeActivated(int id)
 {
-	int iIndex = m_Actions.xmlExpandNode->popupMenu()->indexOf(id) + 3; // +1 because zero based, +1 because it start from level 2, +1 because ...
-	view->expandNode(iIndex);
+	view->expandNode(id);
 }
 
 /** Called when menu item from Collapse Node button is selected */
 void KXMLEditorApp::slotCollapseNodeActivated(int id)
 {
-	int iIndex = m_Actions.xmlCollapseNode->popupMenu()->indexOf(id) + 3;
-	view->collapseNode(iIndex);
+	view->collapseNode(id);
 }
 
 /** Configure application toolbars */
@@ -1029,12 +975,12 @@ void KXMLEditorApp::slotConfigure()
 /** Called, when user press Apply or Ok button in Options dialog */
 void KXMLEditorApp::slotConfigurationChanged()
 {
-	view->getElementsTreeView()->setRootIsDecorated(OptionsDialog::m_AppOptionsMisc.bRootDecorated);
+	view->getElementsTreeView()->setRootIsDecorated(OptionsDialog::getTreeViewRootDecorated());
 
-	view->getElementsTreeView()->setAcceptDrops(OptionsDialog::m_AppOptionsMisc.bEnableDragDrop);
-  view->getElementsTreeView()->viewport()->setAcceptDrops(OptionsDialog::m_AppOptionsMisc.bEnableDragDrop);
+	view->getElementsTreeView()->setAcceptDrops(OptionsDialog::getTreeViewEnableDragDrop());
+  view->getElementsTreeView()->viewport()->setAcceptDrops(OptionsDialog::getTreeViewEnableDragDrop());
 
-	if(OptionsDialog::m_AppOptionsMisc.iElemDisplayMode == 0)
+	if(OptionsDialog::getTreeViewElemDisplayMode() == 0)
 		{ if(view->getElementsTreeView()->columns() == 3)
 				view->getElementsTreeView()->removeColumn(2);
 		}
@@ -1043,6 +989,9 @@ void KXMLEditorApp::slotConfigurationChanged()
 				view->getElementsTreeView()->addColumn(i18n("Attributes"));
 				view->updateStringAttrLists();
 		}
+
+	// save the new configuration to our config file
+	OptionsDialog::saveConfiguration(config);
 }
 
 
