@@ -2,7 +2,7 @@
                           kxmleditorview.cpp  -  description
                              -------------------
     begin                : t ec 10 12:39:26 CEST 2001
-    copyright            : (C) 2001 by Lumir Vanek
+    copyright            : (C) 2001 by The KXMLEditor Team
     email                : lvanek@eanet.cz
  ***************************************************************************/
 
@@ -58,38 +58,30 @@ KXMLEditorView::KXMLEditorView(QWidget *parent, const char *name)
 
   // create tree view, that display XML tree structure --------------
 	m_pTreeViewElements = new XmlTreeView(this, "Tree view", getDocument());
-	
+
 	connect(m_pTreeViewElements, SIGNAL(selectionChanged(QListViewItem *)), this, SLOT(slotElemViewSelChanged(QListViewItem *)));
 	connect(m_pTreeViewElements, SIGNAL(rightButtonPressed(QListViewItem*, const QPoint&, int)), this, SLOT(slotElemViewRButtonPr(QListViewItem*, const QPoint&, int)));
 	connect(m_pTreeViewElements, SIGNAL(doubleClicked(QListViewItem*)), this, SLOT(slotElemViewDoubleClicked(QListViewItem *)));
 	connect(m_pTreeViewElements, SIGNAL(contentsChanged()), this, SLOT(slotElemViewContentsChanged()));
-	
-	// create horizontal splitter -------------------------------------
-	m_pSplitterHorizontal = new QSplitter(this, "Horizontal splitter");
-	m_pSplitterHorizontal->setOrientation(Vertical);
-	m_pSplitterHorizontal->setOpaqueResize(TRUE);
-	
+
 	// create tab widget ----------------------------------------------
-	m_pTabWidget = new QTabWidget(m_pSplitterHorizontal, "Tab");
+	m_pTabWidget = new QTabWidget(this, "Tab");
 
   // create list view, that display XML attributes list -------------
   m_pTableAttributes = new TableWidget(0, 2, m_pTabWidget, "Attribute view");
-	m_pTabWidget->addTab(m_pTableAttributes, QIconSet(UserIcon("xml_attribute")), "Attributes");
-	QHeader* pHeaderHorizontal = m_pTableAttributes->horizontalHeader();
-	pHeaderHorizontal->setLabel(0, i18n("Attribute name"));
-	pHeaderHorizontal->setLabel(1, i18n("Attribute value"));
-		
+	m_pTabWidget->addTab(m_pTableAttributes, QIconSet(UserIcon("xml_attribute")), i18n("Attributes") );
+
 	m_pTabWidget->setTabEnabled(m_pTableAttributes, false);
 
-	connect(m_pTableAttributes, SIGNAL(rightButtonPressed(const QPoint&)), this, SLOT(slotAttrViewRButtonPr(const QPoint&)));
+	connect(m_pTableAttributes, SIGNAL(sigRightButtonPressed(const QPoint&)), this, SLOT(slotAttrViewRButtonPr(const QPoint&)));
 	connect(m_pTableAttributes, SIGNAL(valueChanged(int, int)), this, SLOT(slotAttrViewValueChanged(int, int)));
 
 	// create edit widget, that display XML contents
 	m_pLineEditContents = new QMultiLineEdit(m_pTabWidget, "Edit");
-	m_pTabWidget->addTab(m_pLineEditContents, QIconSet(UserIcon("xml_contents")), "Contents");
+	m_pTabWidget->addTab(m_pLineEditContents, QIconSet(UserIcon("xml_contents")), i18n("Contents") );
 	m_pLineEditContents->setReadOnly(true);
 	m_pTabWidget->setTabEnabled(m_pLineEditContents, false);
-	
+
 	// create pixmaps ---------------------------------------------------
 	XmlTreeItem::m_pPixmapElement = new QPixmap(UserIcon("xml_element"));
 	XmlTreeItem::m_pPixmapText = new QPixmap(UserIcon("xml_text"));
@@ -155,6 +147,7 @@ void KXMLEditorView::slotElemViewSelChanged(QListViewItem* item)
 	m_pTableAttributes->setNumRows(0);
 	m_pLineEditContents->clear();
 	
+	ASSERT(item);
 	XmlTreeItem* pSelectedTreeItem = static_cast<XmlTreeItem *> (item);
 	
 	// choose appropriate object kind
@@ -959,7 +952,8 @@ void KXMLEditorView::editPaste()
   			
 	m_pTreeViewElements->pasteItem(pSelectedTreeItem, QApplication::clipboard()->data());
 	
-	emit sigSelectedElementChanged(static_cast <XmlTreeItem*> (pSelectedItem));
+	if(pSelectedItem)
+		emit sigSelectedElementChanged(static_cast <XmlTreeItem*> (pSelectedItem));
 }
 
 /** Move tree selection to parent item */
