@@ -2,7 +2,7 @@
                           optionsdialog.cpp  -  description
                              -------------------
     begin                : Tue Jul 10 2001
-    copyright            : (C) 2001 by Lumir Vanek
+    copyright            : (C) 2001 by The KXMLEditor Team
     email                : lvanek@eanet.cz
  ***************************************************************************/
 
@@ -28,10 +28,12 @@
 
 #include <klocale.h>
 #include <kiconloader.h>
+#include <kconfig.h>
 
-OptionsDialog::SAppOptionsMisc			OptionsDialog::m_AppOptionsMisc;
+OptionsDialog::SAppOptionsTreeView			OptionsDialog::m_AppOptionsTreeView;
 OptionsDialog::SAppOptionsTarGzExt 	OptionsDialog::m_AppOptionsTarGzExt;
 OptionsDialog::SAppOptionsSpecChars	OptionsDialog::m_AppOptionsSpecChars;
+OptionsDialog::SAppOptionsXml				OptionsDialog::m_AppOptionsXml;
 
 OptionsDialog::OptionsDialog(QWidget *parent, const char *name, bool bModal)
  : KDialogBase(IconList,
@@ -44,7 +46,8 @@ OptionsDialog::OptionsDialog(QWidget *parent, const char *name, bool bModal)
                true
               )
 {
-	setupMiscPage();
+	setupXmlPage();
+	setupTreeViewPage();
 	setupTarGzExtPage();
 	setupSpecCharactersPage();
 }
@@ -53,60 +56,56 @@ OptionsDialog::~OptionsDialog()
 {
 }
 
-/** Setup page with misc. options  */
-void OptionsDialog::setupMiscPage()
+/** Setup page with TreeView. options  */
+void OptionsDialog::setupTreeViewPage()
 {
-	QFrame *pPage = addPage(i18n("Miscellaneous"),
-													i18n("Various properties"),
-													KGlobal::instance()->iconLoader()->loadIcon("misc", KIcon::NoGroup, KIcon::SizeMedium)
+	QFrame *pPage = addPage(i18n("Tree View"),
+													i18n("Tree View properties"),
+													KGlobal::instance()->iconLoader()->loadIcon("view_tree", KIcon::NoGroup, KIcon::SizeMedium)
 												 );
 	QVBoxLayout *pTopLayout = new QVBoxLayout(pPage, 0, spacingHint());
 	if(pTopLayout == 0)
 		return;
 		
-	QGridLayout *pGbox = new QGridLayout(5, 2);
+	QGridLayout *pGbox = new QGridLayout(4, 2);
 	pTopLayout->addLayout(pGbox);
 	
-	m_WidgetsMisc.pCheckBoxRootDecorated = new QCheckBox(i18n("Set root element &decorated"), pPage, "setrootdecorated");
-	m_WidgetsMisc.pCheckBoxRootDecorated->setChecked(m_AppOptionsMisc.bRootDecorated);
-	pGbox->addWidget(m_WidgetsMisc.pCheckBoxRootDecorated, 0, 0);
+	m_WidgetsTreeView.pCheckBoxRootDecorated = new QCheckBox(i18n("Set root element &decorated"), pPage, "setrootdecorated");
+	m_WidgetsTreeView.pCheckBoxRootDecorated->setChecked(m_AppOptionsTreeView.bRootDecorated);
+	pGbox->addWidget(m_WidgetsTreeView.pCheckBoxRootDecorated, 0, 0);
 
 	pGbox->addWidget(new QLabel(i18n("After open file, expand to level:"), pPage, "expandtolabel"), 1, 0);
-	m_WidgetsMisc.pLineEditExpandToLevel = new QLineEdit(pPage, "expandtolevel");
-	m_WidgetsMisc.pLineEditExpandToLevel->setMaxLength(2);
-	QIntValidator *pIntValidator = new QIntValidator(m_WidgetsMisc.pLineEditExpandToLevel);
+	m_WidgetsTreeView.pLineEditExpandToLevel = new QLineEdit(pPage, "expandtolevel");
+	m_WidgetsTreeView.pLineEditExpandToLevel->setMaxLength(2);
+	QIntValidator *pIntValidator = new QIntValidator(m_WidgetsTreeView.pLineEditExpandToLevel);
 	pIntValidator->setRange(0, 99);
-	m_WidgetsMisc.pLineEditExpandToLevel->setValidator(pIntValidator);
-	m_WidgetsMisc.pLineEditExpandToLevel->setText(QString().setNum(m_AppOptionsMisc.iExpandToLevel));
-	pGbox->addWidget(m_WidgetsMisc.pLineEditExpandToLevel, 1, 1);
+	m_WidgetsTreeView.pLineEditExpandToLevel->setValidator(pIntValidator);
+	m_WidgetsTreeView.pLineEditExpandToLevel->setText(QString().setNum(m_AppOptionsTreeView.iExpandToLevel));
+	pGbox->addWidget(m_WidgetsTreeView.pLineEditExpandToLevel, 1, 1);
 	
-	m_WidgetsMisc.pCheckBoxAppendCRLF = new QCheckBox(i18n("&Append CR LF at end of line"), pPage, "appendcrlf");
-	m_WidgetsMisc.pCheckBoxAppendCRLF->setChecked(m_AppOptionsMisc.bAppendCRLF);
-	pGbox->addWidget(m_WidgetsMisc.pCheckBoxAppendCRLF, 2, 0);
+	m_WidgetsTreeView.pCheckBoxEnableDragDrop = new QCheckBox(i18n("Enable &Drag and Drop"), pPage, "enablednd");
+	m_WidgetsTreeView.pCheckBoxEnableDragDrop->setChecked(m_AppOptionsTreeView.bEnableDragDrop);
+	pGbox->addWidget(m_WidgetsTreeView.pCheckBoxEnableDragDrop, 2, 0);
 	
-	m_WidgetsMisc.pCheckBoxEnableDragDrop = new QCheckBox(i18n("Enable &Drag and Drop"), pPage, "enablednd");
-	m_WidgetsMisc.pCheckBoxEnableDragDrop->setChecked(m_AppOptionsMisc.bEnableDragDrop);
-	pGbox->addWidget(m_WidgetsMisc.pCheckBoxEnableDragDrop, 3, 0);
-	
-	m_WidgetsMisc.pButtonGroupElemDisplayMode = new QButtonGroup(i18n("XML Elements - what display in tree"), pPage);
-	pGbox->addWidget(m_WidgetsMisc.pButtonGroupElemDisplayMode, 4, 0);
+	m_WidgetsTreeView.pButtonGroupElemDisplayMode = new QButtonGroup(i18n("XML Elements - what display in tree"), pPage);
+	pGbox->addWidget(m_WidgetsTreeView.pButtonGroupElemDisplayMode, 3, 0);
 	pTopLayout->addStretch(1);
-	QGridLayout *pGridLayoutRadio = new QGridLayout(m_WidgetsMisc.pButtonGroupElemDisplayMode, 3, 1, 20);	
+	QGridLayout *pGridLayoutRadio = new QGridLayout(m_WidgetsTreeView.pButtonGroupElemDisplayMode, 3, 1, 20);	
 	
-	m_WidgetsMisc.pRadioBtnDisplOnlyElements = new QRadioButton(i18n("Only element name"), m_WidgetsMisc.pButtonGroupElemDisplayMode);
-	pGridLayoutRadio->addWidget(m_WidgetsMisc.pRadioBtnDisplOnlyElements, 1, 0, AlignTop);
-	m_WidgetsMisc.pRadioBtnDisplAttrNames = new QRadioButton(i18n("Element, attribute names"), m_WidgetsMisc.pButtonGroupElemDisplayMode);
-	pGridLayoutRadio->addWidget(m_WidgetsMisc.pRadioBtnDisplAttrNames, 2, 0, AlignTop);
-	m_WidgetsMisc.pRadioBtnDisplAttrValues = new QRadioButton(i18n("Element, attributes names and its values"), m_WidgetsMisc.pButtonGroupElemDisplayMode);
-	pGridLayoutRadio->addWidget(m_WidgetsMisc.pRadioBtnDisplAttrValues, 3, 0, AlignTop);
-	switch(m_AppOptionsMisc.iElemDisplayMode)
-		{ case 0:	m_WidgetsMisc.pRadioBtnDisplOnlyElements->setChecked(true);
+	m_WidgetsTreeView.pRadioBtnDisplOnlyElements = new QRadioButton(i18n("Only element name"), m_WidgetsTreeView.pButtonGroupElemDisplayMode);
+	pGridLayoutRadio->addWidget(m_WidgetsTreeView.pRadioBtnDisplOnlyElements, 1, 0, AlignTop);
+	m_WidgetsTreeView.pRadioBtnDisplAttrNames = new QRadioButton(i18n("Element, attribute names"), m_WidgetsTreeView.pButtonGroupElemDisplayMode);
+	pGridLayoutRadio->addWidget(m_WidgetsTreeView.pRadioBtnDisplAttrNames, 2, 0, AlignTop);
+	m_WidgetsTreeView.pRadioBtnDisplAttrValues = new QRadioButton(i18n("Element, attributes names and its values"), m_WidgetsTreeView.pButtonGroupElemDisplayMode);
+	pGridLayoutRadio->addWidget(m_WidgetsTreeView.pRadioBtnDisplAttrValues, 3, 0, AlignTop);
+	switch(m_AppOptionsTreeView.iElemDisplayMode)
+		{ case 0:	m_WidgetsTreeView.pRadioBtnDisplOnlyElements->setChecked(true);
 							break;
 							
-			case 1:	m_WidgetsMisc.pRadioBtnDisplAttrNames->setChecked(true);
+			case 1:	m_WidgetsTreeView.pRadioBtnDisplAttrNames->setChecked(true);
 							break;
 							
-			case 2:	m_WidgetsMisc.pRadioBtnDisplAttrValues->setChecked(true);
+			case 2:	m_WidgetsTreeView.pRadioBtnDisplAttrValues->setChecked(true);
 							break;
 							
 			default: ASSERT(false);
@@ -336,6 +335,48 @@ void OptionsDialog::slotListSpecCharsSelChanged()
   	}
 }
 
+void OptionsDialog::setupXmlPage()
+{
+	QFrame *pPage = addPage(i18n("XML"),
+													i18n("XML properties"),
+													KGlobal::instance()->iconLoader()->loadIcon("kxmleditor", KIcon::NoGroup, KIcon::SizeMedium)
+												 );
+	QVBoxLayout *pTopLayout = new QVBoxLayout(pPage, 0, spacingHint());
+	if(pTopLayout == 0)
+		return;
+		
+	QGridLayout *pGbox = new QGridLayout(3, 2);
+	pTopLayout->addLayout(pGbox);
+
+	m_WidgetsXml.pButtonGroupParser = new QButtonGroup(i18n("XML Parser"), pPage);
+	pGbox->addWidget(m_WidgetsXml.pButtonGroupParser, 0, 0);
+	pTopLayout->addStretch(1);
+	QGridLayout *pGridLayoutRadio = new QGridLayout(m_WidgetsXml.pButtonGroupParser, 2, 1, 20);	
+	
+	m_WidgetsXml.pRadioBtnParserSAX2 = new QRadioButton(i18n("SAX2"), m_WidgetsXml.pButtonGroupParser);
+	pGridLayoutRadio->addWidget(m_WidgetsXml.pRadioBtnParserSAX2, 1, 0, AlignTop);
+	m_WidgetsXml.pRadioBtnParserDOM = new QRadioButton(i18n("DOM"), m_WidgetsXml.pButtonGroupParser);
+	pGridLayoutRadio->addWidget(m_WidgetsXml.pRadioBtnParserDOM, 2, 0, AlignTop);
+	switch(m_AppOptionsXml.eParser)
+		{ case parserSAX2:	m_WidgetsXml.pRadioBtnParserSAX2->setChecked(true);
+												break;
+							
+			case parserDOM:		m_WidgetsXml.pRadioBtnParserDOM->setChecked(true);
+												break;
+							
+			default: ASSERT(false);
+		}
+		
+	m_WidgetsXml.pCheckBoxDontConvertAmpersand = new QCheckBox(i18n("Don't convert ampersand"), pPage);
+	m_WidgetsXml.pCheckBoxDontConvertAmpersand->setChecked(m_AppOptionsXml.bDontConvertAmpersand);
+	pGbox->addWidget(m_WidgetsXml.pCheckBoxDontConvertAmpersand, 1, 0);
+	
+	m_WidgetsXml.pCheckBoxAppendCRLF = new QCheckBox(i18n("&Append CR LF at end of line"), pPage, "appendcrlf");
+	m_WidgetsXml.pCheckBoxAppendCRLF->setChecked(m_AppOptionsXml.bAppendCRLF);
+	pGbox->addWidget(m_WidgetsXml.pCheckBoxAppendCRLF, 2, 0);
+	
+}
+
 /** Called when user press OK button */
 void OptionsDialog::slotOk()
 {
@@ -346,47 +387,101 @@ void OptionsDialog::slotOk()
 /** Called when user press Apply button */
 void OptionsDialog::slotApply()
 {
-	switch(activePageIndex())
-		{ case pageMisc:		m_AppOptionsMisc.bRootDecorated = m_WidgetsMisc.pCheckBoxRootDecorated->isChecked();
-												m_AppOptionsMisc.iExpandToLevel = m_WidgetsMisc.pLineEditExpandToLevel->text().toInt();
-												m_AppOptionsMisc.bAppendCRLF = m_WidgetsMisc.pCheckBoxAppendCRLF->isChecked();
-												m_AppOptionsMisc.bEnableDragDrop = m_WidgetsMisc.pCheckBoxEnableDragDrop->isChecked();
-												
-												if(m_WidgetsMisc.pRadioBtnDisplOnlyElements->isChecked())
-													m_AppOptionsMisc.iElemDisplayMode = 0;
-												else
-													{ if(m_WidgetsMisc.pRadioBtnDisplAttrNames->isChecked())
-															m_AppOptionsMisc.iElemDisplayMode = 1;
-														else
-															m_AppOptionsMisc.iElemDisplayMode = 2;
-													}
-													
-												break;
-												
-			case pageTarGzExt:
-										    { m_AppOptionsTarGzExt.strListOfTarGzExtensions.clear();
-										
-										      QListViewItem *pItem = m_WidgetsTarGzExt.pListView->firstChild();
-													while(pItem)
-														{ m_AppOptionsTarGzExt.strListOfTarGzExtensions.append(pItem->text(0));
-														  pItem = pItem->nextSibling();
-														}			
-										    }
-										    break;
-			
-		  case pageSpecChars:
-										    { m_AppOptionsSpecChars.strListOfSpecCharacters.clear();
-										
-										      QListViewItem *pItem = m_WidgetsSpecChars.pListView->firstChild();
-													while(pItem)
-														{ m_AppOptionsSpecChars.strListOfSpecCharacters.append(pItem->text(0));
-														  pItem = pItem->nextSibling();
-														}			
-										    }
-										    break;
-		
-		}
+	// Xml page
+	if(m_WidgetsXml.pRadioBtnParserSAX2->isChecked())
+		m_AppOptionsXml.eParser = parserSAX2;
+	else
+		m_AppOptionsXml.eParser = parserDOM;
+
+	m_AppOptionsXml.bDontConvertAmpersand = m_WidgetsXml.pCheckBoxDontConvertAmpersand->isChecked();
+	m_AppOptionsXml.bAppendCRLF = m_WidgetsXml.pCheckBoxAppendCRLF->isChecked();
+	
+	// TreeView page
+	m_AppOptionsTreeView.bRootDecorated = m_WidgetsTreeView.pCheckBoxRootDecorated->isChecked();
+	m_AppOptionsTreeView.iExpandToLevel = m_WidgetsTreeView.pLineEditExpandToLevel->text().toInt();
+	m_AppOptionsTreeView.bEnableDragDrop = m_WidgetsTreeView.pCheckBoxEnableDragDrop->isChecked();
+
+	if(m_WidgetsTreeView.pRadioBtnDisplOnlyElements->isChecked())
+		m_AppOptionsTreeView.iElemDisplayMode = 0;
+	else
+	{
+		if(m_WidgetsTreeView.pRadioBtnDisplAttrNames->isChecked())
+			m_AppOptionsTreeView.iElemDisplayMode = 1;
+		else
+			m_AppOptionsTreeView.iElemDisplayMode = 2;
+	}
+
+	// TarGz page
+	m_AppOptionsTarGzExt.strListOfTarGzExtensions.clear();
+
+	QListViewItem *pTarGzItem = m_WidgetsTarGzExt.pListView->firstChild();
+	while(pTarGzItem)
+	{
+		m_AppOptionsTarGzExt.strListOfTarGzExtensions.append(pTarGzItem->text(0));
+		pTarGzItem = pTarGzItem->nextSibling();
+	}
+
+	// SpecChars page
+	m_AppOptionsSpecChars.strListOfSpecCharacters.clear();
+
+	QListViewItem *pSpecCharsItem = m_WidgetsSpecChars.pListView->firstChild();
+	while(pSpecCharsItem)
+	{
+		m_AppOptionsSpecChars.strListOfSpecCharacters.append(pSpecCharsItem->text(0));
+		pSpecCharsItem = pSpecCharsItem->nextSibling();
+	}
+
 	emit configurationChanged();
 }
 
+void OptionsDialog::readConfiguration( KConfig * pConfig )
+{
+	pConfig->setGroup("XML");
+	m_AppOptionsXml.eParser = static_cast <enXmlParser> (pConfig->readNumEntry("Parser", 0)) ;
+	m_AppOptionsXml.bDontConvertAmpersand = pConfig->readBoolEntry("Don't convert ampersand", false);
+	m_AppOptionsXml.bAppendCRLF = pConfig->readBoolEntry("Append CR LF", false);
+	
+	pConfig->setGroup("Tree View");
+	m_AppOptionsTreeView.iExpandToLevel = pConfig->readNumEntry("Expand to level", 5);
+	m_AppOptionsTreeView.bRootDecorated = pConfig->readBoolEntry("Root decorated", false);
+	m_AppOptionsTreeView.bEnableDragDrop = pConfig->readBoolEntry("Enable DnD", true);
+	m_AppOptionsTreeView.iElemDisplayMode = pConfig->readNumEntry("Element display mode", 0);
 
+	pConfig->setGroup("TarGz Extensions");
+	pConfig->readListEntry("Extensions", m_AppOptionsTarGzExt.strListOfTarGzExtensions);
+
+	pConfig->setGroup("Spec. Characters");
+	pConfig->readListEntry("Characters", m_AppOptionsSpecChars.strListOfSpecCharacters);
+}
+
+void OptionsDialog::saveConfiguration( KConfig * pConfig )
+{
+	pConfig->setGroup("XML");
+	pConfig->writeEntry("Parser", m_AppOptionsXml.eParser);
+	pConfig->writeEntry("Don't convert ampersand", m_AppOptionsXml.bDontConvertAmpersand);
+	pConfig->writeEntry("Append CR LF", m_AppOptionsXml.bAppendCRLF);
+	
+	pConfig->setGroup("Tree View");
+	pConfig->writeEntry("Root decorated", m_AppOptionsTreeView.bRootDecorated);
+	pConfig->writeEntry("Expand to level", m_AppOptionsTreeView.iExpandToLevel);
+	pConfig->writeEntry("Enable DnD", m_AppOptionsTreeView.bEnableDragDrop);
+	pConfig->writeEntry("Element display mode", m_AppOptionsTreeView.iElemDisplayMode);
+
+	pConfig->setGroup("TarGz Extensions");
+	pConfig->writeEntry("Extensions", m_AppOptionsTarGzExt.strListOfTarGzExtensions);
+
+	pConfig->setGroup("Spec. Characters");
+	pConfig->writeEntry("Characters", m_AppOptionsSpecChars.strListOfSpecCharacters);
+
+	pConfig->sync();
+}
+
+bool OptionsDialog::getTreeViewRootDecorated() { return m_AppOptionsTreeView.bRootDecorated; }
+unsigned int OptionsDialog::getTreeViewExpandToLevel() { return m_AppOptionsTreeView.iExpandToLevel; }
+bool OptionsDialog::getTreeViewEnableDragDrop() { return m_AppOptionsTreeView.bEnableDragDrop; }
+int OptionsDialog::getTreeViewElemDisplayMode() { return m_AppOptionsTreeView.iElemDisplayMode; }
+QStrList OptionsDialog::getListOfTarGzExtensions() { return m_AppOptionsTarGzExt.strListOfTarGzExtensions; }
+QStrList OptionsDialog::getListOfSpecCharacters() { return m_AppOptionsSpecChars.strListOfSpecCharacters; }
+OptionsDialog::enXmlParser OptionsDialog::getXmlParser() { return m_AppOptionsXml.eParser; }
+bool OptionsDialog::getXmlDontConvertAmpersand() { return m_AppOptionsXml.bDontConvertAmpersand; }
+bool OptionsDialog::getXmlAppendCRLF() { return m_AppOptionsXml.bAppendCRLF; }
