@@ -2,7 +2,7 @@
                           xml_base.cpp  -  description
                              -------------------
     begin                : Tue Jul 10 2001
-    copyright            : (C) 2001 by Lumir Vanek
+    copyright            : (C) 2001 by The KXMLEditor Team
     email                : lvanek@eanet.cz
  ***************************************************************************/
 
@@ -15,8 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "xmltreeview.h"
+#include <klistview.h>
 #include "optionsdialog.h"
+#include "searchdlg.h"
 
 #include "xml_base.h"
 
@@ -74,7 +75,7 @@ const QCString XmlTreeItem::contentsTypeAsText() const
 																				
 				case XmlTreeItem::itemProcInstr:			
 																				return m_strSubtypeXML_procins;
-			
+
 				case XmlTreeItem::itemText:			
 																				return m_strSubtypeXML_text;
 						
@@ -100,7 +101,7 @@ bool XmlTreeItem::acceptsDrops(const QStrList &formats)
 						 formats.contains("text/" + m_strSubtypeXML_comment) ||
 						 formats.contains("text/" + m_strSubtypeXML_procins)
 						);
-						
+
 	if(itemType() == itemProcInstr)
 		return (formats.contains("text/" + m_strSubtypeXML_procins));
 	
@@ -144,7 +145,7 @@ QString XmlTreeItem::path(const XmlTreeItem *) const
 		  strPath = pXmlTreeItemParent->path(this);
 		}
 		
-	// dot separator	
+	// dot separator
 	if(strPath.length() > 0)
 		strPath += ".";
 	
@@ -189,13 +190,36 @@ XmlTreeItem * XmlElement::searchPath(const QString & strPath)
 				{ XmlTreeItem *pFoundXmlTreeItem = pChildXmlTreeItem->searchPath(strPathChild);
 				  return pFoundXmlTreeItem;
 				}
-				
+
 			pChildXmlTreeItem = (XmlTreeItem*) pChildXmlTreeItem->nextSibling();
     }
-	
+
 	return 0;
 }
 
+XmlTreeItem * XmlTreeItem::nextItem()
+{
+	// checking for a child
+	QListViewItem * pTmp = firstChild();
+	if (pTmp)
+		return static_cast <XmlTreeItem *> (pTmp);
+
+	// there is no child -> checking for the next sibling
+	pTmp = nextSibling();
+	if (pTmp)
+		return static_cast <XmlTreeItem *> (pTmp);
+
+	// there is no next sibling -> checking for parnet's next sibling
+	QListViewItem * pParent = parent();
+	while (pParent)
+	{
+		pTmp = pParent->nextSibling();
+		if (pTmp)
+			return static_cast <XmlTreeItem *> (pTmp);
+		pParent = pParent->parent();
+	}
+	return 0;
+}
 
 /** Enable/disable bookmark on this tree item */
 bool XmlTreeItem::toggleBookmark()
@@ -254,7 +278,7 @@ void XmlTreeItem::expandNode(int iLevel, int iCurrentLevel)
 //
 //-------------------------------------------------------------------
 
-XmlProcessingInstruction::XmlProcessingInstruction(XmlTreeView *pParent, const QString &strTarget, const QString &strData)
+XmlProcessingInstruction::XmlProcessingInstruction(KListView *pParent, const QString &strTarget, const QString &strData)
 	: XmlTreeItem(pParent, strTarget + " " + strData, 0)
 {
 	m_strTarget = strTarget;
@@ -294,7 +318,7 @@ void XmlProcessingInstruction::save(QString &strXml, unsigned int iTabLevel)
 	strXml += m_strTarget + " " + m_strData;
 	strXml += " ?>";
 	
-	if(OptionsDialog::m_AppOptionsMisc.bAppendCRLF)
+	if(OptionsDialog::getXmlAppendCRLF())
 		strXml += "\r\n";
 	else
 		strXml += "\n";								
@@ -339,15 +363,22 @@ XmlTreeItem::enSearchResult XmlProcessingInstruction::searchString(const QString
 	// *ppFoundItem contain pointer to selected item, as input parameter.
 	if(*ppFoundItem == this)
 		*pbReachedSelectedItem = true;
-	
-	return searchNotFound;	
+
+	return searchNotFound;
+}
+
+/** Tests, if the corresponding XML object matches the conditions of the given search. */
+bool XmlProcessingInstruction::match( const SearchDlg * const pConditions ) const
+{
+	// TODO implement later - after extension of SearchDlg for Proc.Instr.'s
+	return false;
 }
 
 /** Set Proccessing instruction Target and data from string */
 bool XmlProcessingInstruction::setContents(const QString &strXML)
 {
 	int iLength = strXML.length();
-	
+
 	if(iLength < 6)
 		return false; // min. string must contain <?x ?>
 		
@@ -385,7 +416,7 @@ bool XmlProcessingInstruction::setContents(const QString &strXML)
 //
 //-------------------------------------------------------------------
 
-XmlContentsItem::XmlContentsItem(XmlTreeView *pParent, const QString &strContents, enItemType eItemType)
+XmlContentsItem::XmlContentsItem(KListView *pParent, const QString &strContents, enItemType eItemType)
 	: XmlTreeItem(pParent, 0, 0)
 {
 	setContents(strContents);
@@ -418,7 +449,7 @@ void XmlContentsItem::setContents(const QString &strContents)
 						{ iCrPosition = strLine.find('\n');
 							if(iCrPosition > 0)
 								strLine.replace(iCrPosition, 1, " ");
-						
+
 						  strName += strLine;
 						}
 						
@@ -489,12 +520,12 @@ void XmlContentsItem::save(QString &strXml, unsigned int iTabLevel)
 																			strXml += "<!-- ";
 																			strXml += m_strContents;
 																			strXml += " -->";
-																			if(OptionsDialog::m_AppOptionsMisc.bAppendCRLF)
+																			if(OptionsDialog::getXmlAppendCRLF())
 																				strXml += "\r\n";
 																			else
 																				strXml += "\n";	
 																			break;
-																					
+
 			  default:									ASSERT(false);
 			}
 }
@@ -539,8 +570,22 @@ XmlTreeItem::enSearchResult XmlContentsItem::searchString(const QString &strSear
 	// *ppFoundItem contain pointer to selected item, as input parameter.
 	if(*ppFoundItem == this)
 		*pbReachedSelectedItem = true;
-	
-	return searchNotFound;	
+
+	return searchNotFound;
+}
+
+/** Tests, if the corresponding XML object matches the conditions of the given search. */
+bool XmlContentsItem::match( const SearchDlg * const pConditions ) const
+{
+	if ( pConditions->m_bContents )
+	{
+		if ( m_strContents.find(pConditions->m_strSearchedString, 0, pConditions->m_bMatchCase) >= 0 )
+			return true;
+		else
+			return false;
+	}
+	else
+		return false;
 }
 
 //-------------------------------------------------------------------
@@ -549,7 +594,7 @@ XmlTreeItem::enSearchResult XmlContentsItem::searchString(const QString &strSear
 //
 //-------------------------------------------------------------------
 
-XmlElement::XmlElement(XmlTreeView *pParent, const QString& strName, const QString& namespaceURI)
+XmlElement::XmlElement(KListView *pParent, const QString& strName, const QString& namespaceURI)
 	: XmlTreeItem(pParent, strName, namespaceURI)
 {
 	m_listOfAttributes.setAutoDelete(true);		// automaticaly cleanup memory when destructing
@@ -601,7 +646,7 @@ XmlTreeItem::enSearchResult XmlElement::searchString(const QString &strSearchedS
 				}
 		}
 
-	
+
 	// *ppFoundItem contain pointer to selected item, as input parameter.
 	// We must start search in *ppFoundItem *childs*, not in *ppFoundItem.
 	if(*ppFoundItem == this)
@@ -611,7 +656,7 @@ XmlTreeItem::enSearchResult XmlElement::searchString(const QString &strSearchedS
 	XmlTreeItem* pChildXmlTreeItem = (XmlTreeItem*) firstChild();
   while(pChildXmlTreeItem)
 		{ enSearchResult searchResult;
-				
+
 			searchResult = pChildXmlTreeItem->searchString(strSearchedString,
 																													 bMatchCase,
 																													 bElementNames,
@@ -619,7 +664,7 @@ XmlTreeItem::enSearchResult XmlElement::searchString(const QString &strSearchedS
 																													 bAttributeValues,
 																													 bContents,
 																													 ppFoundItem,
-																													 pbReachedSelectedItem	
+																													 pbReachedSelectedItem
 																							 		 				);
 			if(searchResult > searchNotFound)
 					return searchResult;
@@ -629,15 +674,40 @@ XmlTreeItem::enSearchResult XmlElement::searchString(const QString &strSearchedS
 
 	return searchNotFound;
 }
+
+/** Tests, if the corresponding XML object matches the conditions of the given search. */
+bool XmlElement::match( const SearchDlg * const pConditions ) const
+{
+	if ( ( pConditions->m_bElementNames ) &&
+	     ( text(0).find( pConditions->m_strSearchedString, 0, pConditions->m_bMatchCase ) >= 0 ) )
+		return true;
+
+	if ( ( ! pConditions->m_bAttributeNames ) && ( ! pConditions->m_bAttributeValues ) )
+		return false;
+
+	for ( QListIterator<XmlAttribute> it(m_listOfAttributes); it.current(); ++it )
+	{
+		if ( ( pConditions->m_bAttributeNames ) &&
+		     ( it.current()->name().find(pConditions->m_strSearchedString, 0, pConditions->m_bMatchCase) >= 0 ) )
+			return true;
+
+		if ( ( pConditions->m_bAttributeValues ) &&
+		     ( it.current()->value().find(pConditions->m_strSearchedString, 0, pConditions->m_bMatchCase) >= 0 ) )
+			return true;
+	}
+
+	return false;
+}
+
 /** Save XML to string */
 void XmlElement::save(QString &strXml, unsigned int iTabLevel)
 {
 	QString strTabs;
 	strTabs.fill('\t', iTabLevel);
-	
+
 	// XML element name
-	strXml += strTabs + "<" + text(0);	
-	
+	strXml += strTabs + "<" + text(0);
+
 	// XML attributes list
 	XmlAttribute* pXmlAttribute;
 
@@ -656,7 +726,7 @@ void XmlElement::save(QString &strXml, unsigned int iTabLevel)
 	
 	if((pChildXmlTreeItem == 0))
 		{ strXml += "/>";
-			if(OptionsDialog::m_AppOptionsMisc.bAppendCRLF)
+			if(OptionsDialog::getXmlAppendCRLF())
 				strXml += "\r\n";
 			else
 			strXml += "\n";	
@@ -676,7 +746,7 @@ void XmlElement::save(QString &strXml, unsigned int iTabLevel)
   	}
 
 	if(nChilds > 0)
-		{ if(OptionsDialog::m_AppOptionsMisc.bAppendCRLF)
+		{ if(OptionsDialog::getXmlAppendCRLF())
 				strXml += "\r\n";
 			else
 				strXml += "\n";	
@@ -696,7 +766,7 @@ void XmlElement::save(QString &strXml, unsigned int iTabLevel)
 	// close tag
 	strXml += "</" + text(0) + ">";
 	
-	if(OptionsDialog::m_AppOptionsMisc.bAppendCRLF)
+	if(OptionsDialog::getXmlAppendCRLF())
 		strXml += "\r\n";
 	else
 		strXml += "\n";			
@@ -730,7 +800,7 @@ QString XmlElement::path(const XmlTreeItem *pItemCaller) const
 /** Update column with list of attributes */
 void XmlElement::updateStringAttrList()
 {
-	if(OptionsDialog::m_AppOptionsMisc.iElemDisplayMode == 0)
+	if(OptionsDialog::getTreeViewElemDisplayMode() == 0)
 		return;
 	
 	QString	strAttributesList;
@@ -739,10 +809,10 @@ void XmlElement::updateStringAttrList()
 	for(pXmlAttribute = m_listOfAttributes.first();
 			pXmlAttribute != 0;
 			pXmlAttribute = m_listOfAttributes.next())
-				{ if(OptionsDialog::m_AppOptionsMisc.iElemDisplayMode >= 1)
+				{ if(OptionsDialog::getTreeViewElemDisplayMode() >= 1)
 			  		{ strAttributesList += " " + pXmlAttribute->name();
 			  		}
-			  	if(OptionsDialog::m_AppOptionsMisc.iElemDisplayMode >= 2)
+			  	if(OptionsDialog::getTreeViewElemDisplayMode() >= 2)
 			  		{ strAttributesList += "=\"" + pXmlAttribute->value() + "\"";
 			  		}
 				}
@@ -785,7 +855,10 @@ QString prepareXmlForSave(const QString &strSource)
 					case '>':	strDestination += "&gt;";
 											break;
 											
-				  case '&':	strDestination += "&amp;";
+				  case '&':	  if(OptionsDialog::getXmlDontConvertAmpersand())
+				  							strDestination += strSource[i];
+				  						else
+				  							strDestination += "&amp;";
 											break;
 											
 					case '\"':	strDestination += "&quot;";
@@ -799,7 +872,7 @@ QString prepareXmlForSave(const QString &strSource)
 				  							{ QString strRepresentation;
 				  								strRepresentation.sprintf("&#x%x;", ch.unicode()); // french oe ligature will be saved as &#x153; etc
 				  								
-				  								if(OptionsDialog::m_AppOptionsSpecChars.strListOfSpecCharacters.contains(strRepresentation))
+				  								if(OptionsDialog::getListOfSpecCharacters().contains(strRepresentation))
 				  									strDestination += strRepresentation;
 				  								else
 				  									strDestination += strSource[i];
